### 状态码

本文档介绍所有状态码的含义及描述



#### code码含义

SDK接口回调GyResponse的code含义

| 返回值 | 描述                      |
| :----- | :------------------------ |
| 30000  | 业务成功                  |
| 30004  | 初始化失败                |
| 30005  | 一键登录获取token失败     |
| 30007  | 本机号码校验获取token失败 |



#### errorCode码含义

SDK接口回调GYResponse的errorCode含义

| 返回值 | 描述                                                         |
| :----- | :----------------------------------------------------------- |
| 0      | 成功                                                         |
| -10000 | sdk没有初始化，请先初始化sdk                                 |
| -10001 | sdk初始化失败，详见整体msg内容                               |
| -10003 | 接口请求超时，请稍后重试、加大超时时间或者检查网络           |
| -10006 | 上一个请求正在进行中，请稍后重试                             |
| -10009 | 其他错误，详见整体msg内容，比如metadata字段等会有更详细的内容 |
| -20100 | 传入参数错误                                                 |
| -20101 | appid为空                                                    |
| -20102 | appid无效或者签名无效                                        |
| -20104 | 预登录无效，请先进行预登录                                   |
| -20200 | 无网络可用，请检查手机网络、或者稍后重试                     |
| -20201 | 未插手机电话卡                                               |
| -20202 | 未开启蜂窝网络                                               |
| -20203 | 不支持的运营商，请检查手机是否成功连接运营商、以及sdk支持该运营商 |
| -20301 | 登录授权页退出                                               |
| -20500 | 获取运营商APPID失败，请重启应用重试、或者联系技术支持        |
| -30001 | 服务器返回的其他错误，详见整体metadata内容                   |
| -40001 | 运营商返回的其他错误，详见整体metadata内容，会有更详细的内容 |
| -20303 | 用户点击了切换登录按钮                                       |
| -20304 | 启动登录授权页失败                                           |



#### metadata.code 的含义

SDK接口回调GYResponse存在metadata时，且格式为`{"code":xxxx ,"desc":xxxxx}`

##### 一键登录

| 返回码 | 说明                                                 | 常见原因                                             | 解决方法                                                     |
| :----- | :--------------------------------------------------- | :--------------------------------------------------- | :----------------------------------------------------------- |
| 10010  | pre_get_token 接口网络错误                           | 断网，超时或者跨域                                   | 检测网络                                                     |
| 10012  | pre_get_token 返回错误                               | 数据格式不对                                         | 1: 数据参数传入错误，appID是否传入 2: 检查是否账户费用不足 3: 服务查看日志 |
| 10030  | 移动获取pretoken接口网络失败                         | 断网，超时或者跨域                                   | 检测网络                                                     |
| 10031  | 移动获取token失败                                    | 授权页面获取token失败                                | 1: 网络是否异常 2: 查看是否输入的是开起数据流量的手机号码 3: 检测网络,服务查看日志 |
| 10032  | 移动获取脱敏手机号失败，非移动流量访问或者非本机号码 | 非移动流量访问                                       | 1:检查是否开启的是移动流量数据 2:是否开启代理模式            |
| 10033  | 移动获取脱敏手机号失败                               | 是否是数据网络，备案Referer是否与当前页面Referer一致 | 1:确认备案Referer，与实际使用页面地址是否一致; 2:确认是否添加header代码； 3:检测网络， 服务查看日志 |
| 10040  | 联通获取token失败                                    | 是否是数据网络                                       | 检测网络，服务查看日志                                       |
| 10041  | 联通验签失败                                         | 联通验签失败或者IP鉴权错误                           | 1: 检测网络，查看是否使用的是联通数据网络; 2: 查看是否开启数据代理模式; 3: 联系个验相关人员，查看日志 |
| 40000  | 目前不支持当前运营商                                 | 当前不支持电信取号                                   | 建议降级走其他验证形式                                       |
| 30001  | 关闭授权页                                           | 授权页面用户点击返回按钮，关闭授权                   | 用户关闭授权页                                               |
| 30002  | 用户点击切换其他登录方式按钮，关闭授权页             | 授权页面用户用户点击切换其他登录方式按钮，关闭授权   | 用户关闭授权页                                               |
| 10051  | 电信预取号失败                                       | 网络或者Referer是否与当前页面Referer一致             | 检查是否开启电信网络,检查备案信息                            |
| 10052  | 电信授权失败或者校验失败                             | 非本机号码或请求超限制                               | 联系个验相关人员，查看日志                                   |



##### 本机校验

| 返回码 | 说明                        | 常见原因                                         | 解决方法                                                     |
| :----- | :-------------------------- | :----------------------------------------------- | :----------------------------------------------------------- |
| 100    | pre_gateway接口网络失败     | 断网，超时或者跨域                               | 检测网络                                                     |
| 101    | pre_gateway接口返回数据错误 | 数据格式不对                                     | 查看文档确认格式正确                                         |
| 102    | 接口网络失败                | 断网，超时或者跨域                               | 检测网络                                                     |
| 103    | 电信接口失败                | 是否是数据网络                                   | 检测网络，服务查看日志                                       |
| 104    | 移动接口失败                | 是否是数据网络，备案refer是否与当前页面refer一致 | 1、确认备案refer，与实际使用页面地址是否一致； 2、确认是否添加header代码； 3、检测网络， 服务查看日志 |
| 105    | record_token接口网络失败    | 断网，超时或者跨域                               | 检测网络                                                     |
| 106    | record_token接口失败        | 是否是数据网络                                   | 检测网络，服务查看日志                                       |
| 107    | 联通接口失败                | 是否是数据网络                                   | 检测网络，服务查看日志                                       |
| 108    | 切换运营商接口失败          | 接口超时错误                                     | 检测网络，服务查看日志                                       |

[
](https://docs.geetest.com/onelogin/deploy/Returncode#小程序返回码)

##### 移动

| 返回码 | 描述                                                         | 处理方式                                                     |
| :----- | :----------------------------------------------------------- | :----------------------------------------------------------- |
| 102507 | 登录超时（授权页点登录按钮时，网络信号较差或者配置的超时时间较短 | 在网络信号较好的地方重试，或者修改 SDK 超时时间配置，适当延长超时时间 |
| 103102 | 包签名错误（后台填写的 APPID 和对应的包名包签名必须一致）    | 检查应用的包名、包签名与后台创建应用时配置的包名与包签名是否一致，核对 APPID 是否正确 |
| 103111 | 错误的运营商请求，可能是用户正在使用代理或者运营商判断失败导致 | 在仅开启数据网络的情况下重试                                 |
| 103511 | 服务器 IP 白名单校验失败                                     | 请联系客服配置 IP 白名单                                     |
| 103911 | token 请求过于频繁，10 分钟内获取 token 且未使用的数量不超过30个 | 限制 token 请求频率                                          |
| 104201 | token 已失效或不存在，重复校验或失效                         | 重启应用后尝试                                               |
| 105001 | 联通卡请求移动 SDK 进行取号失败，或者手机卡运营商识别错误    | 升级最新版本 SDK 或者提供错误日志联系客服解答                |
| 105002 | 移动取号失败，可能物联网卡，不允许取号                       | 更换其他可正常通话上网的电话卡尝试                           |
| 105003 | 电信卡请求移动 SDK 进行取号失败，或者手机卡运营商识别错误    | 升级最新版本 SDK 或者提供错误日志联系客服解答                |
| 105012 | 电信卡请求移动 SDK 进行取号失败，或者手机卡运营商识别错误    | 升级最新版本 SDK 或者提供错误日志联系客服解答                |
| 105013 | 联通卡请求移动 SDK 进行取号失败，或者手机卡运营商识别错误    | 升级最新版本 SDK 或者提供错误日志联系客服解答                |
| 200072 | CA根证书校验失败                                             | 一般是开了代理或 VPN 会报错，检查下有没有开代理或 VPN ，或者连接的 wifi 开了代理 |



##### 联通

| 返回码 | 描述                                                         | 处理方式                                           |
| :----- | :----------------------------------------------------------- | :------------------------------------------------- |
| 303    | 应用访问接口次数超日限额                                     | 第二天重试，或增加阈值                             |
| 1001   | 请求已失效                                                   | 同步一下手机设置为北京时间                         |
| 3004   | 使用 3GNET 网络取号失败                                      | 建议使用 4G 网络，或者开关数据网络、飞行模式后重试 |
| 3005   | WIFI 网络下取号失败，或者手机系统限制切换数据失败            | 建议在仅开启数据网络情况下重试                     |
| 3009   | 非联通卡请求SDK SDK 进行取号失败，或者手机卡运营商识别错误   | 升级最新版本 SDK 或者提供错误日志联系客服解答      |
| 3011   | 源 IP 鉴权失败，用户的公网非联通 3/4G 网关的 IP              | 建议切换、开关数据网络或者开关飞行模式后重试       |
| 102001 | 选择流量通道失败，取号功能必须使用流量访问，在 WIFI 和流量同时开启的情况下，SDK 会选择使用流量进行访问，此返回码代表切换失败！（受不同机型的影响） | 在仅开启数据网络的情况下重试                       |
| 201001 | 操作频繁请请稍后再试                                         | 超出 10 分钟之内只能访问 30 次的限制               |
| 302002 | 网络访问异常 SDK                                             | 网络请求异常                                       |
| 302003 | 服务端数据格式出错                                           | 服务端返回数据格式错误                             |
| 1102   | 1、公网 IP 无效 2、同102001 返回码                           | 建议切换 4G 网络，或者开关数据网络、飞行模式后重试 |



##### 电信

| 返回码      | 描述                                                         | 处理方式                                                     |
| :---------- | :----------------------------------------------------------- | :----------------------------------------------------------- |
| -65         | API-request-rates-Exceed-Limitations(调用接口超限),一定时间内连续调用次数较多 | 限制调用频次                                                 |
| -10001      | 取号失败 1、3G 网络取号失败                                  | 1、在 4G 环境下重新尝试 2、建议切换其它登录方式              |
| -10006      | 电信网络，Mdn取号失败，可能是在非 4G 网络下请求              | 换 4G 网络重试                                               |
| -10008      | 超过预设取号阀值                                             | 第二天重试，或增加阈值                                       |
| -10009      | 时间戳过期                                                   | 请确认本机时间是否正确后重试                                 |
| -10016      | 安全参数不完整，安全校验失败                                 | 请确认SDK返回的参数填写正确                                  |
| -8001/80001 | 1、网络异常导致网络请求失败 2、so库匹配错误 3、项目中错误的 `abiFilters`配置 | 1、在4G环境下重新尝试；如果 4G 条件下仍失败，在网络良好的环境下重新尝试 2、重新按照标准检验 so 库是否正确，确认so库按要求导入对应so库 3、检查本地是否存在多余的 so 4、检查项目中的`abiFilters`是否过滤掉设备平台运行必须的 so 库 |
| -8003/80000 | 网络状况较差或者配置的超时时间较短，请求超时                 | 换网络环境好的地方重试                                       |
| -8005/80103 | 调用 SDK 前没有调用初始化方法                                | 在使用天翼账号 SDK 接口之前，必须先调用初始化方法            |
| -8100/80004 | 移动数据网络未开启或者未允许当前 APP 使用移动数据网络        | 需要用户允许 APP 使用移动数据网络                            |
| -8104/80007 | 网络问题导致 IO 异常                                         | 受网络环境以及服务稳定性影响，建议重试                       |
| 30002       | 无法识别用户网络，非电信用户服务识别运营商                   | 返回两个地址可以分别请求，也可以认为是失败                   |
| 51114       | 获取数据不存在 1、AccessCode 只能使用一次 2、AccessCode 过期（默认一小时缓存） | 重新调用预授权接口获取                                       |
| 80102       | so 库匹配异常导致预登录异常                                  | 参考 80001 错误码处理方式                                    |
